# File: NamedVocabulary.py
"""\
This is a small 'wrapper' to access a named vocabulary from
portal_vocabularytool and to fetch its DisplayList

RCS-ID $Id: NamedVocabulary.py 3172 2004-10-13 21:18:00Z yenzenz $
"""
# Copyright (c) 2004-2005 by BlueDynamics Tyrol - Klein & Partner KEG, Austria
#
# BSD-like licence, see LICENCE.txt
#
__author__  = 'Jens Klein <jens.klein@bluedynamics.com>'
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.CMFCore.utils import getToolByName
from Products.Archetypes.interfaces.vocabulary import IVocabulary
from config import TOOL_NAME

class NamedVocabulary:

    vocab_name= None

    __implements__ = (IVocabulary,)

    security = ClassSecurityInfo()
    security.setDefaultAccess('allow')

    def __init__(self, vocabname):
        self.vocab_name = vocabname

    security.declarePublic('getDisplayList')
    def getDisplayList(self, instance):
        """ returns a object of class DisplayList as defined in
            Products.Archetypes.utils.

            The instance of the content class is given as parameter.
        """
        vocab = self.getVocabulary(instance)
        return vocab.getDisplayList(instance)

    security.declarePublic('getVocabularyDict')
    def getVocabularyDict(self, instance):
        """ returns the vocabulary as a dictionary with a string key and a
            string value. If it is not a flat vocabulary, the value is a
            tuple with a string and a sub-dictionary with the same format
            (or None if its a leave).

            The instance of the content is given as parameter.
        """
        vocab = self.getVocabulary(instance)
        return vocab.getVocabularyDict(instance)

    security.declarePublic('isFlat')
    def isFlat(self, instance):
        """ indicates if it is a flat or hierachical vocabulary """

        vocab = self.getVocabulary(instance)
        return vocab.isFlat(instance)

    security.declarePublic('showLeafsOnly')
    def showLeafsOnly(self, instance):
        """ indicates if only leaves or also nots should be shown
        """

        vocab = self.getVocabulary(instance)
        return vocab.showLeafsOnly(instance)


    security.declarePrivate('getVocabulary')
    def getVocabulary(self, instance):
        """ return the vocabulary by name from atvocabularymanager
        """
        vt = getToolByName(instance,TOOL_NAME)
        vocab = vt.getVocabularyByName(self.vocab_name)
        assert(IVocabulary.isImplementedBy(vocab))
        return vocab

# end of class NamedVocabulary
