# File: TreeVocabulary.py
"""\
A Tree Vocabulary is a container for hierachical key/value pairs.

RCS-ID $Id: TreeVocabulary.py 3172 2004-10-13 21:18:00Z yenzenz $
"""
# Copyright (c) 2004-2005 by jens quadrat - Klein & Partner KEG, Austria
#
# BSD-like licence, see LICENCE.txt
#
__author__  = 'Jens Klein <jens.klein@jensquadrat.de>'
__docformat__ = 'plaintext'

from Products.ATVocabularyManager.config import *
if HAS_LINGUA_PLONE:
    from Products.LinguaPlone.public import *
else:
    from Products.Archetypes.atapi import *

from AccessControl import ClassSecurityInfo
from Products.CMFCore.CMFCorePermissions import AddPortalContent
from Products.CMFCore.utils import getToolByName
from Products.Archetypes.interfaces.vocabulary import IVocabulary
try:
    from Products.Archetypes.lib.vocabulary import DisplayList
except ImportError:
    from Products.Archetypes.utils import DisplayList

from Products.ATVocabularyManager.tools import registerVocabularyContainer
from Products.ATVocabularyManager.types.simple import SimpleVocabulary

schema = SimpleVocabulary.schema + Schema((
   BooleanField('ShowLeavesOnly'),
)
)

class TreeVocabulary(SimpleVocabulary):
    security = ClassSecurityInfo()

    schema = schema

    portal_type = meta_type = 'TreeVocabulary'
    archetype_name = 'Tree Vocabulary'   #this name appears in the 'add' box

    def getDisplayList(self, instance):
        """ returns an object of class DisplayList as defined in
            Products.Archetypes.utils

            The instance of the content class is given as parameter.
        """
        dl = DisplayList()
        self._appendToDisplayList(dl, self.getVocabularyDict(instance), None)
        return dl

    def _appendToDisplayList(self, displaylist, vdict, valueparent):
        """ append subtree to flat display list
        """
        print vdict
        for key in vdict.keys():
            if type(vdict[key]) == type((1,2)):
                value  = vdict[key][0]
                subdict= vdict[key][1] or None
            else:
                value  = vdict[key]
                subdict= None
            if valueparent:
                value = '%s - %s' % (valueparent, value)
            if not self.showLeafsOnly() or subdict:
                displaylist.add(key,value)
            if subdict:
                self._appendToDisplayList(displaylist,subdict,value)



    def getVocabularyDict(self, instance):
        """ returns a vocabulary dictionary as defined in the interface """

        vdict = {}
        for obj in self.contentValues():
            vsubdict=obj.getVocabularyDict(instance)
            vdict[obj.getVocabularyKey()] = ( \
                obj.getVocabularyValue(instance),
                vsubdict
            )
        return vdict

    def showLeafsOnly(self):
        """ indicates if only leaves should be shown """
        if hasattr(self,'getShowLeafsOnly'):
            return self.getShowLeafsOnly()
        return None

    def isFlat(self):
        """ indicates if tree or flat """
        return 0



registerType(TreeVocabulary)
registerVocabularyContainer(TreeVocabulary)
# end of class TreeVocabulary
